@@ -30,9 +30,6 @@ class ModuleCheckerSpider(scrapy.Spider):
         entities = response.xpath("//div[@class='Box-row Box-row--focus-gray py-2 d-flex position-relative "
                                   "js-navigation-item ']")
 
-        result = [False, False]
-        index = 0
-
         for entity in entities:
             entity_ = entity.xpath(".//span/a/text()").get()
 
@@ -48,18 +45,9 @@ class ModuleCheckerSpider(scrapy.Spider):
                 ), callback=self.yield_raw_settings, meta={"name": entity_}, errback=self.error_back
             )
 
-        self.cache.put(
-            all(result)
-        )
-
     def yield_raw_settings(self, response):
         raw = response.urljoin(response.xpath("//div[@class='BtnGroup']/a/@href").get())
-
-        self.cache.put(
-            {
-                response.request.meta["name"]: raw
-            }
-        )
+        self.cache[response.request.meta["name"]] = raw
 
         yield {
             "raw_link": raw
